@@ -10,11 +10,11 @@ Regexp::MultiLanguage::JavaScript - JavaScript dialect for Regexp::MultiLanguage
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ sub match_regex {
 		$regex = substr $regex, 1;
 	}
 	
-	return "(value.match($regex)";
+	return "(value.match($regex))";
 }
 
 sub comment_start {
